@@ -77,7 +77,7 @@
 #define VERTICAL_ZOOM_STEP_FACTOR 1.5
 
 /** interval for limiting the number of repaints per second [ms] */
-#define REPAINT_INTERVAL 125
+#define REPAINT_INTERVAL 50
 
 //***************************************************************************
 Kwave::SignalWidget::SignalWidget(QWidget *parent,
@@ -558,11 +558,6 @@ void Kwave::SignalWidget::insertView(Kwave::SignalView *view,
     view->setZoomAndOffset(m_zoom, m_offset);
 
     // connect all signals
-    connect(view,       SIGNAL(sigMouseChanged(Kwave::MouseMark::Mode,
-                                               sample_index_t, sample_index_t)),
-            this,       SIGNAL(sigMouseChanged(Kwave::MouseMark::Mode,
-                                               sample_index_t, sample_index_t)));
-
     connect(view,       SIGNAL(sigCommand(QString)),
 	    this,       SIGNAL(sigCommand(QString)),
 	    Qt::QueuedConnection);
@@ -574,6 +569,10 @@ void Kwave::SignalWidget::insertView(Kwave::SignalView *view,
 	    this,       SLOT(updateMinimumHeight()));
     connect(view,       SIGNAL(destroyed(QObject*)),
 	    this,       SLOT(updateMinimumHeight()));
+    connect(view,       SIGNAL(sigCursorChanged(sample_index_t)),
+	    this,       SIGNAL(sigCursorChanged(sample_index_t)));
+    connect(this,       SIGNAL(sigCursorChanged(sample_index_t)),
+	    view,       SLOT(showCursor(sample_index_t)));
 
     updateMinimumHeight();
 }
