@@ -51,13 +51,13 @@ namespace Kwave
 	 * when OK has been pressed.
 	 * @see Kwave::Plugin::setup
 	 */
-	virtual QStringList *setup(QStringList &previous_params);
+	QStringList *setup(QStringList &previous_params) Q_DECL_OVERRIDE;
 
 	/**
 	 * Saves the files, using the settings made in "setup()"
 	 * @see Kwave::Plugin::start()
 	 */
-	virtual int start(QStringList &params);
+	int start(QStringList &params) Q_DECL_OVERRIDE;
 
 	/** mode for numbering the output files */
 	typedef enum {
@@ -173,14 +173,6 @@ namespace Kwave
 	QString createDisplayList(const QStringList &list,
                                   unsigned int max_entries) const;
 
-	/**
-	 * Escape all parts of a string that might be dangerous for using
-	 * within a file name, like "/" and similar.
-	 * @param text unescaped text
-	 * @return escaped string, which should be safe to use in a file name
-	 */
-	QString escapeForFileName(const QString &text);
-
     private:
 
 	/** the URL of the first file (user selection) */
